import QtQuick 2.7
import QtQuick.VirtualKeyboard 2.1
import QtQuick.VirtualKeyboard.Styles 2.0

InputPanel {
    id: root

    property int _yVisible: parent.height - root.height
    property int _yInvisible: parent.height

    z: 89

    state: "invisible"
    states: [
        State {
            name: "visible"
            /*  The visibility of the InputPanel can be bound to the Qt.inputMethod.visible property,
            but then the handwriting input panel and the keyboard input panel can be visible
            at the same time. Here the visibility is bound to InputPanel.active property instead,
            which allows the handwriting panel to control the visibility when necessary.
        */
            when: Qt.inputMethod.visible === true && active === true
            PropertyChanges {
                target: root
                y: _yVisible
            }
        },
        State {
            name: "invisible"
            /*  The visibility of the InputPanel can be bound to the Qt.inputMethod.visible property,
            but then the handwriting input panel and the keyboard input panel can be visible
            at the same time. Here the visibility is bound to InputPanel.active property instead,
            which allows the handwriting panel to control the visibility when necessary.
        */
            when: Qt.inputMethod.visible === false || active === false
            PropertyChanges {
                target: root
                y: _yInvisible
            }
        }
    ]

    transitions: Transition {
        from: "invisible"
        to: "visible"
        reversible: true
        ParallelAnimation {
            NumberAnimation {
                properties: "y"
                duration: 250
                easing.type: Easing.InOutQuad
            }
        }
    }
}
